================================================================================
{{name}}
================================================================================

.. image:: https://api.travis-ci.org/{{organisation}}/{{name}}.svg?branch=master
   :target: http://travis-ci.org/{{organisation}}/{{name}}

.. image:: https://codecov.io/github/{{organisation}}/{{name}}/coverage.png
    :target: https://codecov.io/github/{{organisation}}/{{name}}

{%block documentation_link%}
.. image:: https://readthedocs.org/projects/{{name|lower}}/badge/?version=latest
   :target: http://{{name|lower}}.readthedocs.org/en/latest/
{%endblock%}


Installation
================================================================================

You can install it via pip:

.. code-block:: bash

    $ pip install {{name}}


or clone it and install it:

.. code-block:: bash

    $ git clone http://github.com/{{organisation}}/{{name}}.git
    $ cd {{name}}
    $ python setup.py install
